******************************************************************************************
* Impulse response function aggregate level (VECM model)
******************************************************************************************

/*Aggregate data containing Rotterdam price and average gasoline price data by day*/
use prix_gaz_jour.dta, clear

generate Date=mdy(m,j,a) 
format Date %d
sort Date
gen id=_n
tset id

*In log, for gasoline prices and Rotterdam prices
gen lPrixHT=log(prixht_gaz)
gen lGazoleRotterdam=log(gazolerotterdam)


capture program drop IRF
program IRF 
args yvar xvar lagLT lagY lagX table

*long term relationship and residual
quietly reg `yvar' L`lagLT'.`xvar' 
cap drop res lagres 
predict res, res
gen lagres=L1.res

*Long term parameter
scalar LT=_b[L`lagLT'.`xvar']
scalar LT_90=LT*0.9

*Price increase and decrease
cap drop D`yvar' D`xvar' 
gen D`yvar'=(D.`yvar')
gen D`xvar'=(D.`xvar')

*definitions of lag variables
local pY0 
local pX0 D`xvar' 

forvalues i = 1(1) 15 {
local j=`i'-1 
local pY`i' `pY`j'' L`i'.D`yvar' 
local pX`i' `pX`j'' L`i'.D`xvar'
}

*short term relationship

quietly reg D`yvar' `pY`lagY'' `pX`lagX'' lagres, noconstant

*Impulse response function
local nirf = `lagY' + `lagX' + 2 

cap matrix drop coeff
matrix coeff = e(b)

forvalues i = 0(1) 91 {
cap matrix drop A`i'
cap matrix drop V`i'
}
forvalues i = 1(1) 91 {
cap matrix drop S`i'
}
cap matrix drop B
cap matrix drop IRF

*Creation of matrices A & B
matrix define A0=J(`nirf',`nirf',0)
matrix define A1=J(`nirf',`nirf',0)

forvalues i = 1(1) `nirf' {
matrix A1[1,`i']=coeff[1,`i']
matrix A1[`nirf',`i']=coeff[1,`i']
matrix A1[`nirf',`nirf']=coeff[1,`nirf']+1
}
local lagY1 = `lagY' - 1 
forvalues i = 1(1) `lagY1' {
matrix A1[`i'+1,`i']=1
}
forvalues i = 1(1) `lagX' {
matrix A1[`i'+`lagY'+1,`i'+`lagY']=1
}

matrix define B=J(`nirf',1,0)
matrix B[1,1]=-coeff[1,`nirf']*LT
matrix B[`nirf',1]=-coeff[1,`nirf']*LT 

matrix define S1=I(`nirf')

*Shock
matrix define V0=J(`nirf',1,0)
matrix V0[`lagX'+1,1]=1

*IRF
forvalues j = 2(1) 91 {
local k=`j'-1
matrix A`j'=A`k'*A1
matrix S`j'=A`k'+S`k'
}
forvalues j = 1(1) 91 {
local k=`j'-1
local l=`j'-2
matrix V`j'=A`j'*V0+S`j'*B
}

matrix IRF=J(91,3,0)
forvalues j = 1(1) 91 {
matrix IRF[`j',1]=`j'-1
matrix IRF[`j',2]=V`j'[`nirf',1]
matrix IRF[`j',3]=LT_90
}
*Table
ssc install xsvmat, replace
xsvmat IRF, saving(`table',replace)
use `table'.dta, clear
rename IRF1 day
rename IRF2 IRF
rename IRF3 LT90
twoway line (IRF LT90) day

end

IRF lPrixHT lGazoleRotterdam 0 7 7 tableLog0

IRF lPrixHT lGazoleRotterdam 6 7 7 tableLog6    

IRF prixht_gaz gazolerotterdam 0 7 7 tableNiv0

IRF prixht_gaz gazolerotterdam 6 7 7 tableNiv6





